@@ -106,8 +106,8 @@ class TTree(object):
             raise Exception("Baskets of all branches should have the same length")
 
         if flush:
-            for key, value in branchdict.items():
-                self._branches[key].newbasket(value)
+            self.extend(branchdict, flush=False)
+            self.flush()
         else:
             for key, value in branchdict.items():
                 for x in value:
@@ -121,10 +121,10 @@ class TTree(object):
                         self._branches[key]._branch.treecheck = 0
 
     def append(self, branchdict):
-        for value in branchdict.values:
-            if len(value) != 1:
-                raise Exception("The length of all the baskets should be 1")
-        self.extend(branchdict, flush=False)
+        appenddict = {}
+        for key, value in branchdict.items():
+            appenddict[key] = [value]
+        self.extend(appenddict, flush=False)
 
     def flush(self):
         for key in self._branches.keys():
